@@ -15,7 +15,7 @@ else:
 
 
 def _load_codeformatters() -> Dict[str, Callable[[str, str], str]]:
-    codeformatter_entrypoints = importlib_metadata.entry_points().get(  # type: ignore
+    codeformatter_entrypoints = importlib_metadata.entry_points().get(
         "mdformat.codeformatter", ()
     )
     return {ep.name: ep.load() for ep in codeformatter_entrypoints}
@@ -47,7 +47,7 @@ class ParserExtensionInterface(Protocol):
 
 
 def _load_parser_extensions() -> Dict[str, ParserExtensionInterface]:
-    parser_extension_entrypoints = importlib_metadata.entry_points().get(  # type: ignore  # noqa: E501
+    parser_extension_entrypoints = importlib_metadata.entry_points().get(
         "mdformat.parser_extension", ()
     )
     return {ep.name: ep.load() for ep in parser_extension_entrypoints}
